prices_and_variants = """
    <html>
        <body>
            <h2 class="name" itemprop="name">EasyBook Pro 15</h2>
            <div id="price">Was 999.9</div>
            <div id="sale-price">499.9</div>
            <p class="instock availability">
                <i class="icon-ok"></i>
                In stock (10 available)
            </p>
            <div id="color-variants">
                Colors:
                <div class="color" stock="true">
                    <span class="color-name">Black</span>
                    <img src="https://demo.com/imgs/black-1.jpg">
                </div>
                <div class="color" stock="false">
                    <span class="color-name">Gray</span>
                    <img src="https://demo.com/imgs/black-1.jpg">
                </div>
            </div>
        </body>
    </html>
"""

item_with_breadcrumbs = """
    <html>
        <body>
            <div class="breadcrumbs">
                <div class="breadcrumb">Home</div>
                <div class="breadcrumb">Phone</div>
                <div class="breadcrumb">Smartphone</div>
            </div>
            <h2 class="name">
                <div class="brand">EasyData</div>
                Test Product Item
            </h2>
            <input value="smartphone" content="phone" name="category" />
            <a id="url" href="https://demo.com/product/123">Item Link</a>
            <div class="images">
                <img src="https://demo.com/img1.jpg" />
                <img src="https://demo.com/img2.jpg" />
                <img src="https://demo.com/img3.jpg" />
            </div>
        </body>
    </html>
"""

sizes = """
    <ul id="size-variants">
        <li size-stock="true" class="in-stock">
            <input class="size-variant" value="l">
            l
        </li>
        <li size-stock="false">
            <input class="size-variant" value="xl">
            xl
        </li>
        <li size-stock="true" class="in-stock">
            <input class="size-variant" value="xxl">
            xxl
        </li>
    </ul>
"""

categories = """
    <div id="notebook">
        <p class="type">Laptop</p>
        <p class="name">EasyBook Pro 15</p>
    </div>
    <div id="accessory">
        <p class="type">Accessory</p>
        <p class="name">Phone case 15</p>
    </div>
"""

features = """
    <div id="description">
        <ul class="features">
            <li>Material: aluminium <span>MATERIAL</span></li>
            <li>style: <strong>elegant</strong> is this</li>
            <li>Date added: Fri, 12 Dec 2018 10:55</li>
        </ul>
        <table class="table specs">
            <tr>
                <th>Product Type</th>
                <td>Books</td>
            </tr>
            <tr>
                <th>Price (excl. tax)</th>
                <td>£51.77</td>
            </tr>
        </table>
        <table class="table2 specs2">
            <tr>
                <th>Product Type</th>
                <td>Papers</td>
            </tr>
            <tr>
                <th>Price (dddd. tax)</th>
                <td>£52</td>
            </tr>
        </table>
    </div>
"""

images = """
    <div id="image-container">
        <img id="image" src="https://demo.com/imgs/1.jpg">
        <div id="images">
            <img class="image" src="https://demo.com/imgs/1.jpg">
            <img class="image" src="https://demo.com/imgs/2.jpg">
            <img class="image" src="https://demo.com/imgs/3.jpg">
        </div>
    </div>
"""
